@@ -1,8 +1,9 @@
-function match = doctest_compare(want, got, ellipsis)
+function match = doctest_compare(want, got, normalize_whitespace, ellipsis)
 % Matches two strings together.  They should be identical, except:
 %
-%   * the first one can contain '...', which matches anything in
-%     the second (if ellipsis is true)
+%   * multiple spaces are collapsed (if NORMALIZE_WHITESPACE is true);
+%   * the first one can contain '...', which matches anything in the
+%     second (if ELLIPSIS is true);
 %   * they might match after putting "ans = " on the first;
 %   * various other nonsense of unknown current relevance.
 %
@@ -15,8 +16,14 @@ got = regexprep(got, '</a>', '');
 % WHY do they need backspaces?  huh.
 got = regexprep(got, '.\x08', '');
 
-want = strtrim(want);
-got = strtrim(got);
+% collapse multiple spaces to one
+if normalize_whitespace
+    want = strtrim(regexprep(want, '\s+', ' '));
+    got = strtrim(regexprep(got, '\s+', ' '));
+else
+    want = strtrim(strtrim_lines_discard_empties(want));
+    got = strtrim(strtrim_lines_discard_empties(got));
+end
 
 if isempty(got) && (isempty(want) || (ellipsis && strcmp(want, '...')))
     match = 1;
@@ -37,3 +44,18 @@ result = regexp(got, want_re, 'once');
 match = ~ isempty(result);
 
 end
+
+
+function r = strtrim_lines_discard_empties(s)
+  lines = strsplit(s, '\n');
+
+  keep = true(size(lines));
+  for j = 1:length(lines)
+    lines{j} = strtrim(lines{j});
+    if (isempty(lines{j}))
+      keep(j) = false;
+    end
+  end
+  lines = lines(keep);
+  r = strjoin(lines, '');
+end
